==> klogic_1.5.orig.tar.gz: klogic-1.5/klogic/wire.h <==
#ifndef __Wire_CLASS__
#define __Wire_CLASS__

#include <klogicList.h>
#include <device.h>
#include <qpixmap.h>
#include "xdevice.h"

/********************************************
* node handling of all nodes of a wire 
*********************************************/
class Wire
{
public:
	Wire();
	Wire(QPoint);
	~Wire();

	// draw wire
	void drawImage(QPainter *);
	void setColor(QColor);

	// called by XDevice
	// modify input- and output-nodes by devices (device-move)
	void setInputPosition(QPoint);
	void setInputPosition(QPoint, int);
	QPoint getInputPosition(int idx, int selonly = 0);
	void setOutputPosition(QPoint);
	void setOutputPosition(QPoint, int);
	QPoint getOutputPosition(int idx, int selonly = 0);
	// get io-position of connected wire
	QPoint getIOPosition(int idx, int selonly = 0);

	// called by NetDevice
	void garbageCollection();
	QPoint getActive();
	int activeIsInput();
	int activeIsOutput();
	bool activeIsEnd();
	int countNodes();
	int lockNode(QPoint);
	bool lockLastNode();
	int lockSelectedNode();

	// called by Selection
	int getMinSelX();
	int getMaxSelX();
	int getMinSelY();
	int getMaxSelY();
	void addPos(int, int);
	bool isSelected();

	// constants
	static const int NODE_NOLOCK = 0;
	static const int NODE_SINGLE = 1;
	static const int NODE_FRONT = 2;
	static const int NODE_MIDDLE = 3;

	static const int WFAIL = -1;

	// import/export mothods
	void setExportDelta(int dx, int dy);
	void setExportSelected(bool);
	QString operator>> (QString &);
	bool operator<< (const QString &);

protected:
	// erase whole wire (usually use erase)
	void eraseWire(QPainter *);
	// erase active node and end nodes
	void erase(QPainter *);
	// draw all nodes
	void draw(QPainter *);
	// draw grid into rect
	void restoreArry(QPainter *p, int, int, int, int);
	void drawSolderedPoint(QPainter *, QColor, QPoint);

	// wire modifying methods
	KlogicList<QPoint> *contains(QPoint);
	int lockNode(KlogicList<QPoint> *);
	int lockNode(QPoint *);
	bool nodeIsReference(QPoint *);
	bool nodeIsForeign(QPoint *);
	int nodeIsInput(QPoint *);
	int nodeIsOutput(QPoint *);
	int isPart(QPoint *);

	// operations on active (locked) node
	int createNode(QPoint);		// set active node
	void updateNode(QPoint);	// update position of active node
	void cutNode();			// will not destroy it!
	void removeNode();		// destroys active node
	void releaseNode();
	QPoint *getActiveNode();
	bool activeIsReference();	// node is only a copy
	bool activeIsForeign();		// also part of another wire
	int getActiveConnIndex();

	// called by XWire: connection methods
	int connectInput(int);
	void disconnectInput(int);
	int connectOutput(int);
	void disconnectOutput(int);
	int connectWire(int);
	void disconnectWire(int);
	QPoint *checkConnection(QPoint *);

	// wire-part selctions
	bool select(QRect, bool all = false);
	void unselect();

	// current color of the wire
	QColor color;

	// set wire size in pixels
	void setLineSize(int);

	// erase everything before refreshing the wire next time
	void enforceCompleteDrawing();
	bool completeDrawingIsEnforced();

private:
	// *****************************************************
	// import/export
	// *****************************************************
	int string2wire(const char *);	// hist import
	int exp_dx;
	int exp_dy;
	bool exp_selected;

	// *****************************************************
	// connection detection methods
	// *****************************************************
	int derive(QPoint, QPoint, QPoint);
	int inBetween(QPoint, QPoint, QPoint);
	QPoint * align(QPoint *);

	// *****************************************************
	// connection management
	// *****************************************************
	// node of wire, which is input-node (input of a device)
	QPoint *input[2];

	// node of wire, which is output-node (output of a device)
	QPoint *output[2];

	// connection nodes (wire-wire-connections)
	QPoint *io_point[2];

	// connection nodes of other wires (references)
	KlogicList<QPoint> io_point_foreign;

	// *****************************************************
	// moving and drawing management
	// *****************************************************
	// last position of the locked node at time of its drawing
	QPoint o_node;
	QPoint o_start_node;
	QPoint o_end_node;
	// last wire-course (node inserted if not null)
	QPoint o_ins_node1, o_ins_node2;

	// actual locked node with predecessor and successor
	QPoint *from_node;
	QPoint *current_node;
	QPoint *to_node;

	bool bMustErase;

	// *****************************************************
	// the wire
	// *****************************************************
	// all nodes of this wire
	KlogicList<QPoint> wire;

	// all currenty selected nodes of this wire
	KlogicList<QPoint> selnode;

	int size;
	int old_size;
};

#endif

==> klogic-1.6.tar.gz: klogic-1.6/klogic/wire.h <==
#ifndef __Wire_CLASS__
#define __Wire_CLASS__

#include <klogicList.h>
#include <device.h>
#include <qpixmap.h>
#include "xdevice.h"

/********************************************
* node handling of all nodes of a wire 
*********************************************/
class Wire
{
public:
	Wire();
	Wire(QPoint);
	~Wire();

	// draw wire
	void drawImage(QPainter *);
	void setColor(QColor);

	// called by XDevice
	// modify input- and output-nodes by devices (device-move)
	void setInputPosition(QPoint);
	void setInputPosition(QPoint, int);
	QPoint getInputPosition(int idx, int selonly = 0);
	void setOutputPosition(QPoint);
	void setOutputPosition(QPoint, int);
	QPoint getOutputPosition(int idx, int selonly = 0);
	// get io-position of connected wire
	QPoint getIOPosition(int idx, int selonly = 0);

	// called by NetDevice
	void garbageCollection();
	QPoint getActive();
	int activeIsInput();
	int activeIsOutput();
	bool activeIsEnd();
	int countNodes();
	int lockNode(QPoint);
	bool lockLastNode();
	int lockSelectedNode();

	// called by Selection
	int getMinSelX();
	int getMaxSelX();
	int getMinSelY();
	int getMaxSelY();
	void addPos(int, int);
	bool isSelected();

	// constants
	static const int NODE_NOLOCK = 0;
	static const int NODE_SINGLE = 1;
	static const int NODE_FRONT = 2;
	static const int NODE_MIDDLE = 3;

	static const int WFAIL = -1;

	// import/export mothods
	void setExportDelta(int dx, int dy);
	void setExportSelected(bool);
	QString operator>> (QString &);
	bool operator<< (const QString &);

protected:
	// erase whole wire (usually use erase)
	void eraseWire(QPainter *);
	// erase active node and end nodes
	void erase(QPainter *);
	// draw all nodes
	void draw(QPainter *);
	// draw grid into rect
	void restoreArry(QPainter *p, int, int, int, int);
	void drawSolderedPoint(QPainter *, QColor, QPoint);

	// wire modifying methods
	KlogicList<QPoint> *contains(QPoint);
	int lockNode(KlogicList<QPoint> *);
	int lockNode(QPoint *);
	bool nodeIsReference(QPoint *);
	bool nodeIsForeign(QPoint *);
	int nodeIsInput(QPoint *);
	int nodeIsOutput(QPoint *);
	int isPart(QPoint *);

	// operations on active (locked) node
	int createNode(const QPoint&);	// set active node
	void updateNode(QPoint);	// update position of active node
	void cutNode();			// will not destroy it!
	void removeNode();		// destroys active node
	void releaseNode();
	QPoint *getActiveNode();
	bool activeIsReference();	// node is only a copy
	bool activeIsForeign();		// also part of another wire
	int getActiveConnIndex();

	// called by XWire: connection methods
	int connectInput(int);
	void disconnectInput(int);
	int connectOutput(int);
	void disconnectOutput(int);
	int connectWire(int);
	void disconnectWire(int);
	QPoint *checkConnection(QPoint *);

	// wire-part selctions
	bool select(QRect, bool all = false);
	void unselect();

	// current color of the wire
	QColor color;

	// set wire size in pixels
	void setLineSize(int);

	// erase everything before refreshing the wire next time
	void enforceCompleteDrawing();
	bool completeDrawingIsEnforced();

private:
	// *****************************************************
	// import/export
	// *****************************************************
	int string2wire(const char *);	// hist import
	int exp_dx;
	int exp_dy;
	bool exp_selected;

	// *****************************************************
	// connection detection methods
	// *****************************************************
	int derive(QPoint, QPoint, QPoint);
	int inBetween(QPoint, QPoint, QPoint);
	QPoint * align(QPoint *);

	// *****************************************************
	// connection management
	// *****************************************************
	// node of wire, which is input-node (input of a device)
	QPoint *input[2];

	// node of wire, which is output-node (output of a device)
	QPoint *output[2];

	// connection nodes (wire-wire-connections)
	QPoint *io_point[2];

	// connection nodes of other wires (references)
	KlogicList<QPoint> io_point_foreign;

	// *****************************************************
	// moving and drawing management
	// *****************************************************
	// last position of the locked node at time of its drawing
	QPoint o_node;
	QPoint o_start_node;
	QPoint o_end_node;
	// last wire-course (node inserted if not null)
	QPoint o_ins_node1, o_ins_node2;

	// actual locked node with predecessor and successor
	QPoint *from_node;
	QPoint *current_node;
	QPoint *to_node;

	bool bMustErase;

	// *****************************************************
	// the wire
	// *****************************************************
	// all nodes of this wire
	KlogicList<QPoint> wire;

	// all currenty selected nodes of this wire
	KlogicList<QPoint> selnode;

	int size;
	int old_size;
};

#endif
